defmodule Hrx.Entry do
  @moduledoc """
  HRX entry
  """
  defstruct [:path, :contents]

  @type t :: %__MODULE__{
          path: String.t(),
          contents: :directory | {:file, String.t()}
        }

  @spec new({:directory, String.t()} | {:file, {String.t()} | {String.t(), String.t()}}) ::
          Hrx.Entry.t()
  @doc """
  Create a new HRX entry for a file or directory.

  Takes in a record based on the parsed format generated by `Hrx.Parser.parse/2`
  """
  def new({:file, {filename, contents}}),
    do: %__MODULE__{path: filename, contents: {:file, contents}}

  def new({:file, {filename}}), do: %__MODULE__{path: filename, contents: {:file, ""}}
  def new({:directory, directory}), do: %__MODULE__{path: directory, contents: :directory}
end
